@@ -6,7 +6,9 @@ The :doc:`tutorial` provides a helpful walkthrough of most methods.
 
 """
 
-from .core import Cache, Disk, EmptyDirWarning, UnknownFileWarning, Timeout
+from .core import (
+    Cache, Disk, EmptyDirWarning, JSONDisk, UnknownFileWarning, Timeout
+)
 from .core import DEFAULT_SETTINGS, ENOVAL, EVICTION_POLICY, UNKNOWN
 from .fanout import FanoutCache
 from .persistent import Deque, Index
@@ -25,6 +27,7 @@ __all__ = [
     'EmptyDirWarning',
     'FanoutCache',
     'Index',
+    'JSONDisk',
     'Lock',
     'RLock',
     'Timeout',
@@ -36,15 +39,15 @@ __all__ = [
 ]
 
 try:
-    from .djangocache import DjangoCache  # pylint: disable=wrong-import-position
+    from .djangocache import DjangoCache  # noqa
     __all__.append('DjangoCache')
 except Exception:  # pylint: disable=broad-except
     # Django not installed or not setup so ignore.
     pass
 
 __title__ = 'diskcache'
-__version__ = '4.0.0'
-__build__ = 0x040000
+__version__ = '5.0.0'
+__build__ = 0x050000
 __author__ = 'Grant Jenks'
 __license__ = 'Apache 2.0'
-__copyright__ = 'Copyright 2016-2018 Grant Jenks'
+__copyright__ = 'Copyright 2016-2020 Grant Jenks'
